package cn.com.infosec.jce.provider;

import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.Digest;
import cn.com.infosec.crypto.PBEParametersGenerator;
import cn.com.infosec.crypto.digests.MD5Digest;
import cn.com.infosec.crypto.digests.RIPEMD160Digest;
import cn.com.infosec.crypto.digests.SHA1Digest;
import cn.com.infosec.crypto.params.KeyParameter;
import cn.com.infosec.crypto.params.ParametersWithIV;

class OldPKCS12ParametersGenerator extends PBEParametersGenerator {
   public static final int KEY_MATERIAL = 1;
   public static final int IV_MATERIAL = 2;
   public static final int MAC_MATERIAL = 3;
   private Digest digest;
   private int u;
   private int v;

   public OldPKCS12ParametersGenerator(Digest digest) {
      this.digest = digest;
      if (digest instanceof MD5Digest) {
         this.u = 16;
         this.v = 64;
      } else if (digest instanceof SHA1Digest) {
         this.u = 20;
         this.v = 64;
      } else {
         if (!(digest instanceof RIPEMD160Digest)) {
            throw new IllegalArgumentException("Digest " + digest.getAlgorithmName() + " unsupported");
         }

         this.u = 20;
         this.v = 64;
      }

   }

   private void adjust(byte[] a, int aOff, byte[] b) {
      int var10001 = (b[b.length - 1] & 255) + (a[aOff + b.length - 1] & 255) + 1;
      int var6 = aOff + b.length - 1;
      a[var6] = (byte)var10001;
      var6 = var10001 >>> 8;

      for(int var4 = b.length - 2; var4 >= 0; --var4) {
         int var5;
         int var10000 = var5 = var6 + (b[var4] & 255) + (a[var6 = aOff + var4] & 255);
         a[var6] = (byte)var5;
         var6 = var10000 >>> 8;
      }

   }

   private byte[] generateDerivedKey(int idByte, int n) {
      int var3;
      byte[] var4 = new byte[var3 = this.v];
      byte[] var5 = new byte[n];

      int var6;
      for(var6 = 0; var6 != var3; ++var6) {
         var4[var6] = (byte)idByte;
      }

      int var7;
      byte[] idByte1;
      byte[] var17;
      byte[] var10002;
      if ((idByte1 = super.salt) != null && idByte1.length != 0) {
         var17 = new byte[idByte = (var6 = this.v) * ((idByte1.length + var6 - 1) / var6)];

         for(var7 = 0; var7 != idByte; ++var7) {
            var10002 = super.salt;
            var17[var7] = var10002[var7 % var10002.length];
         }
      } else {
         var17 = new byte[0];
      }

      byte[] var18;
      if ((idByte1 = super.password) != null && idByte1.length != 0) {
         var18 = new byte[idByte = (var7 = this.v) * ((idByte1.length + var7 - 1) / var7)];

         for(int var8 = 0; var8 != idByte; ++var8) {
            var10002 = super.password;
            var18[var8] = var10002[var8 % var10002.length];
         }
      } else {
         var18 = new byte[0];
      }

      byte[] var19 = new byte[var7 = var17.length + var18.length];
      idByte = var17.length;
      System.arraycopy(var17, 0, var19, 0, idByte);
      idByte = var17.length;
      var6 = var18.length;
      System.arraycopy(var18, 0, var19, idByte, var6);
      int var9;
      byte[] var10 = new byte[var9 = this.v];
      int var11 = (n + (idByte = this.u) - 1) / idByte;
      byte idByte2 = 1;

      for(int var12 = idByte2; var12 <= var11; var12 = idByte) {
         int var13;
         byte[] var14 = new byte[var13 = this.u];
         this.digest.update(var4, 0, var3);
         this.digest.update(var19, 0, var7);
         this.digest.doFinal(var14, 0);

         for(idByte = 1; idByte != super.iterationCount; ++idByte) {
            this.digest.update(var14, 0, var13);
            this.digest.doFinal(var14, 0);
         }

         for(idByte = 0; idByte != var9; ++idByte) {
            var10[var12] = var14[idByte % var13];
         }

         for(idByte = 0; idByte != var7 / (var6 = this.v); ++idByte) {
            this.adjust(var19, idByte * var6, var10);
         }

         if (var12 == var11) {
            int var20 = var12 - 1;
            var6 = (var12 - 1) * (idByte = this.u);
            idByte = n - var20 * idByte;
            System.arraycopy(var14, 0, var5, var6, idByte);
         } else {
            idByte = (var12 - 1) * this.u;
            System.arraycopy(var14, 0, var5, idByte, var13);
         }

         idByte = var12 + 1;
      }

      return var5;
   }

   public CipherParameters generateDerivedParameters(int keySize) {
      OldPKCS12ParametersGenerator var10000 = this;
      int var2 = keySize / 8;
      byte[] keySize1 = var10000.generateDerivedKey(1, var2);
      return new KeyParameter(keySize1, 0, var2);
   }

   public CipherParameters generateDerivedParameters(int keySize, int ivSize) {
      OldPKCS12ParametersGenerator var10000 = this;
      OldPKCS12ParametersGenerator var10001 = this;
      int var5 = keySize / 8;
      keySize = ivSize / 8;
      byte[] ivSize1 = var10001.generateDerivedKey(1, var5);
      byte[] var3 = var10000.generateDerivedKey(2, keySize);
      KeyParameter var4;
      var4 = new KeyParameter.<init>(ivSize1, 0, var5);
      return new ParametersWithIV(var4, var3, 0, keySize);
   }

   public CipherParameters generateDerivedMacParameters(int keySize) {
      OldPKCS12ParametersGenerator var10000 = this;
      int var2 = keySize / 8;
      byte[] keySize1 = var10000.generateDerivedKey(3, var2);
      return new KeyParameter(keySize1, 0, var2);
   }
}
